@@ -20,7 +20,7 @@
 
 import os
 import unittest
-from pyrocumulus.exceptions import PyrocumulusException
+from pyrocumulus.commands.runtornado import RunTornadoCommand
 
 
 class TornadoApplicationTestCase(unittest.TestCase):
@@ -28,10 +28,6 @@ class TornadoApplicationTestCase(unittest.TestCase):
     Base class for tests with tornado.
     setUpClass() runs a tornado server in background
     and tearDownClass kills it.
-
-    To use it, your setup.py file needs to have the
-    runtornado command - which is included in the
-    pyrocumulus.setupcommands module.
     """
 
     python_exec = 'python'
@@ -40,21 +36,19 @@ class TornadoApplicationTestCase(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
-        if not cls.application:
-            msg = 'You must set an applicatoin to your '
-            msg += 'TornadoApplicationTestCase.\n'
-            msg += 'Something like: "myproject.web.application_instance"'
+        options = ['--daemonize']
+        if cls.application:
+            options.append('--application %s' % cls.application)
 
-            raise PyrocumulusException(msg)
-
-        options = [cls.application, '--daemonize']
         runtornado_cmd_line = cls._mount_runtorando_cmd_line(*options)
 
         os.system(runtornado_cmd_line)
 
     @classmethod
     def tearDownClass(cls):
-        options = [cls.application, '--kill']
+        options = ['--kill']
+        if cls.application:
+            options.append('--application %s' % cls.application)
         runtornado_cmd_line = cls._mount_runtorando_cmd_line(*options)
 
         os.system(runtornado_cmd_line)
